@@ -100,7 +100,9 @@ class CaproverAPI:
                     default_value = input(ask_variable)
                 app_variables[app_variable['id']] = default_value
         for variable_id, variable_value in app_variables.items():
-            raw_app_data = raw_app_data.replace(variable_id, str(variable_value))
+            raw_app_data = raw_app_data.replace(
+                variable_id, str(variable_value)
+            )
         return raw_app_data
 
     def get_system_info(self):
@@ -124,7 +126,9 @@ class CaproverAPI:
                 if not app_info.get("data", {}).get("isAppBuilding"):
                     logging.info("App building finished...")
                     return
-                logging.info("App is still building... sleeping for 1 second...")
+                logging.info(
+                    "App is still building... sleeping for 1 second..."
+                )
             except Exception as e:
                 logging.error(e)
             timeout -= 1
@@ -244,6 +248,41 @@ class CaproverAPI:
     def stop_app(self, app_name: str):
         return self.update_app(app_name=app_name, instance_count=0)
 
+    def delete_app_matching_pattern(
+        self, app_name_pattern: str, delete_volumes: bool = False,
+        automated=False
+    ):
+        """
+        :param app_name_pattern: regex pattern to match app name
+        :param delete_volumes: set to true to delete volumes
+        :param automated: set to tru to disable confirmation
+        :return:
+        """
+        app_list = self.list_apps()
+        for app in app_list.get('data').get("appDefinitions"):
+            app_name = app['appName']
+            if re.search(app_name_pattern, app_name):
+                if not automated:
+                    confirmation = None
+                    while confirmation not in ['y', 'n', 'Y', 'N']:
+                        confirmation = input(
+                            "Do you want to delete app ({})?\n"
+                            "Answer (Y or N): ".format(
+                                app_name
+                            )
+                        )
+                    if confirmation.lower() == 'n':
+                        logging.info("Skipping app deletion...")
+                        continue
+                self.delete_app(
+                    app_name=app['appName'], delete_volumes=delete_volumes
+                )
+                time.sleep(0.20)
+        return {
+            "description": "All apps matching pattern deleted",
+            "status": 100
+        }
+
     def delete_app(self, app_name, delete_volumes: bool = False):
         """
         :param app_name: app name
@@ -251,6 +290,11 @@ class CaproverAPI:
         :return:
         """
         if delete_volumes:
+            logging.info(
+                "Deleting app {} and it's volumes...".format(
+                    app_name
+                )
+            )
             app = self.get_app(app_name=app_name)
             data = json.dumps(
                 {
@@ -261,6 +305,9 @@ class CaproverAPI:
                 }
             )
         else:
+            logging.info(
+                "Deleting app {}".format(app_name)
+            )
             data = json.dumps({"appName": app_name})
         response = requests.post(
             self._build_url(CaproverAPI.APP_DELETE_PATH),
@@ -350,22 +397,43 @@ class CaproverAPI:
         :param app_push_webhook:
         :return: dict
         """
+        current_app_info = self.get_app(app_name=app_name)
+
+        # handle environment_variables
+        # gets current envVars and overwrite with new data
+        current_env_vars = current_app_info["envVars"]
+        current_env_vars_as_dict = {
+            item['key']: item['value'] for item in current_env_vars
+        }
         if environment_variables:
-            env_vars = [
-                {
-                    "key": k, "value": v
-                } for k, v in environment_variables.items()
-            ]
-        else:
-            env_vars = None
+            current_env_vars_as_dict.update(environment_variables)
+        updated_environment_variables = [
+            {
+                "key": k, "value": v
+            } for k, v in current_env_vars_as_dict.items()
+        ]
+        current_app_info['envVars'] = updated_environment_variables
+
+        # handle volumes
+        # gets current volumes and overwrite with new data
+        current_volumes = current_app_info['volumes']
+        current_volumes_as_dict = {
+            item['volumeName']: item['containerPath'] for
+            item in current_volumes
+        }
         if persistent_directories:
-            volumes = [
-                {
-                    "volumeName": volume_data.split(':')[0], "containerPath": volume_data.split(':')[1]
-                } for volume_data in persistent_directories
-            ]
-        else:
-            volumes = None
+            for volume_pair in persistent_directories:
+                volume_name, container_path = volume_pair.split(':')
+                current_volumes_as_dict[volume_name] = container_path
+        updated_volumes = [
+            {
+                "volumeName": volume_name,
+                "containerPath": container_path
+            } for
+            volume_name, container_path in current_volumes_as_dict.items()
+        ]
+        current_app_info['volumes'] = updated_volumes
+
         if port_mapping:
             ports = [
                 {
@@ -383,23 +451,22 @@ class CaproverAPI:
             "notExposeAsWebApp": not expose_as_web_app,
             "forceSsl": force_ssl,
             "websocketSupport": support_websocket,
-            "volumes": volumes,
             "ports": ports,
             "containerHttpPort": container_http_port,
             "description": description,
             "appPushWebhook": app_push_webhook,
             "serviceUpdateOverride": service_update_override,
-            "envVars": env_vars
         }
-        data = {"appName": app_name}
         for k, v in _data.items():
             if v is None:
+                # skip as value not changed
                 continue
-            data[k] = v
+            # update current value with new value
+            current_app_info[k] = v
         logging.info("{} | Updating app info...".format(app_name))
         response = self.session.post(
             self._build_url(CaproverAPI.UPDATE_APP_PATH),
-            headers=self.headers, data=json.dumps(data)
+            headers=self.headers, data=json.dumps(current_app_info)
         )
         return CaproverAPI._check_errors(response)
 
